==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualHardDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the uri of a disk.
 * @property uri Specifies the virtual hard disk's uri.
 */
public data class VirtualHardDiskArgs(
    public val uri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs =
        com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs.builder()
            .uri(uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualHardDiskArgs].
 */
@PulumiTagMarker
public class VirtualHardDiskArgsBuilder internal constructor() {
    private var uri: Output<String>? = null

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("echbgwclumifkved")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("eukffckmdfuhfisp")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): VirtualHardDiskArgs = VirtualHardDiskArgs(
        uri = uri,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualHardDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the uri of a disk.
 * @property uri Specifies the virtual hard disk's uri.
 */
public data class VirtualHardDiskArgs(
    public val uri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs =
        com.pulumi.azurenative.compute.inputs.VirtualHardDiskArgs.builder()
            .uri(uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualHardDiskArgs].
 */
@PulumiTagMarker
public class VirtualHardDiskArgsBuilder internal constructor() {
    private var uri: Output<String>? = null

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("bcvbnfeybfynipgc")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("dcfaeyfmxdhdbbao")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): VirtualHardDiskArgs = VirtualHardDiskArgs(
        uri = uri,
    )
}
